@@ -29,7 +29,7 @@ public:
     explicit SelectConvertParameterWidget(QWidget *parent = nullptr);
     ~SelectConvertParameterWidget();
 
-    QString code() const;
+    Q_REQUIRED_RESULT QString code() const;
     void setCode(const QStringList &code, QString &error);
 
 Q_SIGNALS:
