@@ -28,7 +28,7 @@ public:
     explicit SelectAddHeaderPositionCombobox(QWidget *parent = nullptr);
     ~SelectAddHeaderPositionCombobox();
 
-    QString code() const;
+    Q_REQUIRED_RESULT QString code() const;
     void setCode(const QString &code, const QString &name, QString &error);
 
 Q_SIGNALS:
