@@ -102,9 +102,9 @@ QStringList SieveEditorGraphicalModeWidget::sieveCapabilities()
     return mCapabilities;
 }
 
-QString SieveEditorGraphicalModeWidget::script(QString &requires) const
+QString SieveEditorGraphicalModeWidget::script(QString &required) const
 {
-    return mSieveScript->generatedScript(requires);
+    return mSieveScript->generatedScript(required);
 }
 
 void SieveEditorGraphicalModeWidget::slotAddScriptPage(KSieveUi::SieveScriptPage *page)
@@ -126,10 +126,10 @@ void SieveEditorGraphicalModeWidget::slotActivateScriptPage(QWidget *page)
 
 QString SieveEditorGraphicalModeWidget::currentscript()
 {
-    QString requires;
-    QString script = mSieveScript->generatedScript(requires);
-    if (!requires.isEmpty()) {
-        script.prepend(requires + QLatin1Char('\n'));
+    QString requireModules;
+    QString script = mSieveScript->generatedScript(requireModules);
+    if (!requireModules.isEmpty()) {
+        script.prepend(requireModules + QLatin1Char('\n'));
     }
     return script;
 }
