@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -19,8 +19,7 @@
 #define PARSEUSERJOBTEST_H
 
 #include <QObject>
-namespace KSieveUi
-{
+namespace KSieveUi {
 class ParseUserTest : public QObject
 {
     Q_OBJECT
